/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef egyh
#define egyh

#include <QTreeWidget>
#include <QMap>

class QDragEnterEvent;
class QDragMoveEvent;
class QDropEvent;
class QMouseEvent;
class QMimeData;

class egykl : public QTreeWidget
<%
	Q_OBJECT
	public:
		egykl(QWidget *felvnl, jelzpn *nybnvn);
		jelzpn *kidlgz;

		QMap<int, QTreeWidgetItem*> kket;

		bool prmz(QTreeWidgetItem * eljar, const QString & lnmtat);

		void dropEvent(QDropEvent *);

		bool kitzjl;

	public slots:
		void kivalt(const zagv&);
		void vnl(const QString & lnmtat);
		void eler();
%>;

#endif

